#!/usr/bin/env python3
#
# Copyright(C) 2020 Red Hat, Thoth Team
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""Test model."""

import requests
import json
import os

from tensorflow.keras.datasets import mnist
import matplotlib.pyplot as plt
import numpy as np


(x_train, y_train), (x_test, y_test) = mnist.load_data()

# Convert to float32.
x_test = np.array(x_test, np.float32)

# Normalize images value from [0, 255] to [0, 1].
x_test = x_test / 255.0

addr = os.getenv("THOTH_AIDEVSECOPS_TUTORIAL_MODEL_URL", "http://localhost:8080")
test_url = addr + "/predict"

# prepare headers for http request
headers = {"content-type": "application/json"}

# select one test image
img = x_test[5890]
data = json.dumps({"inputs": img.tolist()})

# Check which image is sent
plt.imshow(img, cmap="gray")
plt.show(block=False)
plt.pause(1)
plt.close()

# send http request with image and receive response
response = requests.post(test_url, data=data, headers=headers)

# decode response
print(response.text)



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AdviseInputLibraryUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"version": "str", "report": "object"}

    attribute_map = {"version": "version", "report": "report"}

    def __init__(self, version=None, report=None):  # noqa: E501
        """AdviseInputLibraryUsage - a model defined in Swagger"""  # noqa: E501
        self._version = None
        self._report = None
        self.discriminator = None
        self.version = version
        self.report = report

    @property
    def version(self):
        """Gets the version of this AdviseInputLibraryUsage.  # noqa: E501


        :return: The version of this AdviseInputLibraryUsage.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AdviseInputLibraryUsage.


        :param version: The version of this AdviseInputLibraryUsage.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError(
                "Invalid value for `version`, must not be `None`"
            )  # noqa: E501

        self._version = version

    @property
    def report(self):
        """Gets the report of this AdviseInputLibraryUsage.  # noqa: E501


        :return: The report of this AdviseInputLibraryUsage.  # noqa: E501
        :rtype: object
        """
        return self._report

    @report.setter
    def report(self, report):
        """Sets the report of this AdviseInputLibraryUsage.


        :param report: The report of this AdviseInputLibraryUsage.  # noqa: E501
        :type: object
        """
        if report is None:
            raise ValueError(
                "Invalid value for `report`, must not be `None`"
            )  # noqa: E501

        self._report = report

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AdviseInputLibraryUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdviseInputLibraryUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
#
# Copyright(C) 2020 Red Hat, Thoth Team
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""Define Model class."""

import os

from pathlib import Path

import tensorflow as tf


class Model:
    """Model to handle prediction for MNIST classification."""

    def __init__(self):
        """Load model once when app starts."""
        # Path to data
        directory_path = Path.cwd()
        trained_model_path = directory_path.joinpath(
            str(os.environ.get("THOTH_AIDEVSECOPS_TRAINED_MODEL_PATH", "models"))
        )
        model_version = str(
            os.environ.get(
                "THOTH_AIDEVSECOPS_MODEL_VERSION", "210124112759-d97fd1f46b13ee40"
            )
        )

        loaded_model = tf.keras.models.load_model(
            f"{trained_model_path}/{model_version}", compile=False
        )
        self.model = loaded_model
        self.model_version = model_version

    def predict(self, image_array):
        """Make prediction using MNIST classifcation model."""
        # reshape
        image = image_array.reshape(1, 28, 28, 1)

        prediction = self.model.predict(image)
        return prediction.argmax(), prediction[0][prediction.argmax()]



#!/usr/bin/env python3
# thamos
# Copyright(C) 2019, 2020 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Test serialization of response from Thoth."""

import json
from base import ThamosTestCase
from pathlib import Path
import toml

from thamos.utils import cwd
from thamos.cli import _write_files


class TestResponse(ThamosTestCase):
    """Test response serialization."""

    def test_serialization(self, tmp_path: Path):
        """Test serialization of a response from backend."""
        response = json.loads((Path(self.data_dir) / "response_1.json").read_text())
        with cwd(str(tmp_path)):
            pipfile = response["result"]["report"]["products"][0]["project"][
                "requirements"
            ]
            pipfile_lock = response["result"]["report"]["products"][0]["project"][
                "requirements_locked"
            ]
            _write_files(pipfile, pipfile_lock, requirements_format="pipenv")

            written_pipfile = toml.loads(Path("Pipfile").read_text())
            assert written_pipfile == {
                "dev-packages": {},
                "packages": {
                    "flask": {"index": "pypi-org", "version": "*"},
                    "tensorflow": {"index": "pypi-org", "version": "*"},
                },
                "source": [
                    {
                        "name": "pypi-org",
                        "url": "https://pypi.org/simple",
                        "verify_ssl": True,
                    }
                ],
                "thoth": {"allow_prereleases": {}, "disable_index_adjustment": False},
            }

            written_pipfile_lock = json.loads(Path("Pipfile.lock").read_text())
            assert written_pipfile_lock == pipfile_lock



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PythonPackageVersionsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"versions": "list[PythonPackageVersionsResponseVersions]"}

    attribute_map = {"versions": "versions"}

    def __init__(self, versions=None):  # noqa: E501
        """PythonPackageVersionsResponse - a model defined in Swagger"""  # noqa: E501
        self._versions = None
        self.discriminator = None
        self.versions = versions

    @property
    def versions(self):
        """Gets the versions of this PythonPackageVersionsResponse.  # noqa: E501


        :return: The versions of this PythonPackageVersionsResponse.  # noqa: E501
        :rtype: list[PythonPackageVersionsResponseVersions]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this PythonPackageVersionsResponse.


        :param versions: The versions of this PythonPackageVersionsResponse.  # noqa: E501
        :type: list[PythonPackageVersionsResponseVersions]
        """
        if versions is None:
            raise ValueError(
                "Invalid value for `versions`, must not be `None`"
            )  # noqa: E501

        self._versions = versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PythonPackageVersionsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPackageVersionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import sys

REQUIRED_PYTHON = "python3"


def main():
    system_major = sys.version_info.major
    if REQUIRED_PYTHON == "python":
        required_major = 2
    elif REQUIRED_PYTHON == "python3":
        required_major = 3
    else:
        raise ValueError("Unrecognized python interpreter: {}".format(REQUIRED_PYTHON))

    if system_major != required_major:
        raise TypeError(
            "This project requires Python {}. Found: Python {}".format(
                required_major, sys.version
            )
        )
    else:
        print(">>> Development environment passes all tests!")


if __name__ == "__main__":
    main()



# type: ignore
# flake8: noqa

"""Configuration file for Jupyter NB Convert."""

## Set the log level by value or name.
c.Application.log_level = "DEBUG"

## The date format used by logging formatters for %(asctime)s
c.Application.log_datefmt = "%Y-%m-%dT%H:%M:%S"

## The Logging format template
# Let's at least try for an logstash format
c.Application.log_format = (
    "{"
    '"@timestamp": "%(asctime)s", '
    '"@version": 1, '
    '"level": "%(levelname)s", '
    '"name": "%(name)s", '
    '"message": "%(message)s"'
    "}"
)

## Writer class used to write the  results of the conversion
c.NbConvertApp.writer_class = "FilesWriter"

## The time to wait (in seconds) for output from executions. If a cell execution
#  takes longer, an exception (TimeoutError on python 3+, RuntimeError on python
#  2) is raised.
#
#  `None` or `-1` will disable the timeout. If `timeout_func` is set, it
#  overrides `timeout`.
c.ExecutePreprocessor.timeout = 1200

## The export format to be used, either one of the built-in formats ['asciidoc',
#  'custom', 'html', 'latex', 'markdown', 'notebook', 'pdf', 'python', 'rst',
#  'script', 'slides'] or a dotted object name that represents the import path
#  for an `Exporter` class
c.NbConvertApp.export_format = "notebook"

## Executes all the cells in a notebook
c.ExecutePreprocessor.enabled = True

## Name of kernel to use to execute the cells. If not set, use the kernel_spec
#  embedded in the notebook.
c.ExecutePreprocessor.kernel_name = "python3"

## Automation specific settings
import os

if os.getenv("RUN_IN_AUTOMATION"):
    from pathlib import Path

    ## Directory to write output(s) to. Defaults to output to the directory of each
    #  notebook. To recover previous default behaviour (outputting to the current
    #  working directory) use . as the flag value.
    base_dir = Path(os.getenv("LOCAL_DATA_PATH"))
    notebook_dir = Path(os.getenv("NOTEBOOK_NAME")).parent
    c.FilesWriter.build_directory = str(base_dir / "notebooks" / notebook_dir)

    ## Whether to apply a suffix prior to the extension (only relevant when
    #  converting to notebook format). The suffix is determined by the exporter, and
    #  is usually '.nbconvert'.
    c.NbConvertApp.use_output_suffix = False



#!/usr/bin/env python3
# thamos
# Copyright(C) 2018, 2019, 2020 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Core parts of library for interacting with Thoth."""

import os
import logging
import typing
import platform
from time import sleep
from time import monotonic
from contextlib import contextmanager
from functools import partial
from functools import wraps
import pprint
import json
import urllib3
import requests

import micropipenv
from termcolor import colored
from yaspin import yaspin
from yaspin.spinners import Spinners
from invectio import gather_library_usage
from thoth.analyzer import run_command
from thoth.python import Project
from thoth.common import ThothAdviserIntegrationEnum
from thoth.common import get_justification_link as jl
from thoth.common import cwd

from . import __version__ as thamos_version
from .swagger_client.rest import ApiException
from .swagger_client import ApiClient
from .swagger_client import BuildAnalysisApi
from .swagger_client import Configuration
from .swagger_client import PythonStack
from .swagger_client import AdviseInput
from .swagger_client import AdviseApi
from .swagger_client import ImageAnalysisApi
from .swagger_client import ProvenanceApi
from .swagger_client import HardwareApi
from .swagger_client import S2iApi
from .swagger_client import PythonPackagesApi
from .swagger_client.models import AnalysisResultResponse
from .config import config as thoth_config
from .exceptions import UnknownAnalysisType
from .exceptions import TimeoutError
from .exceptions import ApiError
from .exceptions import NoDevRequirements
from .exceptions import NoRequirementsFile

from typing import Callable, Any, Union, Dict

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

LAST_ANALYSIS_ID_FILE = ".thoth_last_analysis_id"

_LOGGER = logging.getLogger(__name__)
_RETRY_ON_ERROR_COUNT = int(os.getenv("THAMOS_RETRY_ON_ERROR_COUNT", 3))
_RETRY_ON_ERROR_SLEEP = float(os.getenv("THAMOS_RETRY_ON_ERROR_SLEEP", 3.0))
_THAMOS_TIMEOUT = int(os.getenv("THAMOS_TIMEOUT", 2000))
_SOURCE = {
    "adviser": "advise/python",
    "provenance-checker": "provenance/python",
    "package-extract": "analyze",
}


def with_api_client(func: typing.Callable):
    """Load configuration entries from Thoth configuration file."""
    # noqa
    @wraps(func)
    def wrapper(*args, **kwargs):
        config = Configuration()
        host = thoth_config.explicit_host
        if not host:
            thoth_config.load_config()
            host = thoth_config.content.get("host") or config.host
        thoth_config.api_discovery(host)
        _LOGGER.debug("Using API: %s", thoth_config.api_url)
        config.host = thoth_config.api_url
        config.verify_ssl = thoth_config.tls_verify

        start = monotonic()
        api_client = ApiClient(configuration=config)
        # Override default user-agent.
        api_client.user_agent = (
            f"Thamos/{thamos_version} (Python {platform.python_version()}; "
            f"{platform.system()} {platform.release()})"
        )
        result = func(api_client, *args, **kwargs)
        _LOGGER.debug("Elapsed seconds processing request: %f", monotonic() - start)
        return result

    return wrapper


def is_analysis_ready(analysis_id: str) -> bool:
    """Handle the the multiple response types available while asking for result of a anaylsis result."""
    config = Configuration()
    host = thoth_config.explicit_host
    if not host:
        thoth_config.load_config()
        host = thoth_config.content.get("host") or config.host
    source = analysis_id.rsplit("-", maxsplit=2)[0]
    source_url = _SOURCE.get(source)
    response = requests.get(f"https://{host}/api/v1/{source_url}/{analysis_id}")
    if response.status_code == 202:
        return False
    elif response.status_code in (200, 400):
        # Return true if result is ready.
        return True

    raise ApiError(
        f"Thoth Backend didn't respond with correct status code. Returned code - "
        f"{response.status_code}: {response.text}"
    )


def _wait_for_analysis(status_func: Callable[..., Any], analysis_id: str) -> None:
    """Wait for ongoing analysis to finish."""
    # noqa
    @contextmanager
    def _no_spinner():
        yield

    spinner = partial(
        yaspin,
        Spinners.clock,
        text=f"Waiting for response from Thoth (analysis: {analysis_id})...",
    )  # type: Union[Callable[..., Any], partial[Any]]
    if _LOGGER.getEffectiveLevel() == logging.DEBUG or bool(
        int(os.getenv("THAMOS_NO_PROGRESSBAR", 1))
    ):
        # CLI automatically injects THAMOS_NO_PROGRESSBAR=0 if user did not turned it off explictily.
        spinner = _no_spinner

    sleep_time = 0.5
    retries = 0
    with spinner():
        start_time = monotonic()
        while True:
            if _THAMOS_TIMEOUT and monotonic() - start_time > _THAMOS_TIMEOUT:
                raise TimeoutError(
                    f"Thoth backend did not respond in time, timeout set "
                    f"to {_THAMOS_TIMEOUT} - see {jl('thamos_timeout')}"
                )
            try:
                response = status_func(analysis_id)
            except Exception as exc:
                if retries >= _RETRY_ON_ERROR_COUNT:
                    raise

                retries += 1
                _LOGGER.error("Failed to obtain status from Thoth: %s", str(exc))
                _LOGGER.warning(
                    "Retrying in a few moments... (attempt %d/%d)",
                    retries,
                    _RETRY_ON_ERROR_COUNT,
                )
                sleep(_RETRY_ON_ERROR_SLEEP)
                continue

            retries = 0  # Reset counter as we obtained a valid response.
            if response:
                break

            if _LOGGER.getEffectiveLevel() <= logging.DEBUG:
                _LOGGER.debug(
                    "Waiting for %r to finish for %g seconds (state: %s)",
                    analysis_id,
                    sleep_time,
                    (get_status(analysis_id) or {}).get("state", "N/A"),
                )

            sleep(sleep_time)
            sleep_time = min(sleep_time * 2, 8)


def _note_last_analysis_id(analysis_id: str) -> None:
    """Store analysis id in a temporary file to keep analysis id for thamos log optional."""
    if int(os.getenv("THAMOS_DISABLE_LAST_ANALYSIS_ID_FILE", 0)):
        _LOGGER.debug("Last analysis id will not be noted")
        return

    _LOGGER.debug("Noting last analysis id %r", analysis_id)
    try:
        with open(LAST_ANALYSIS_ID_FILE, "w") as analysis_id_file:
            analysis_id_file.write(analysis_id)
    except Exception as exc:
        _LOGGER.warning("Failed to write analysis id to a temporary file: %s", str(exc))


def _get_last_analysis_id() -> str:
    """Retrieve last analysis id from a temporary file."""
    try:
        with open(LAST_ANALYSIS_ID_FILE, "r") as analysis_id_file:
            analysis_id = analysis_id_file.readline().strip()
    except Exception as exc:
        raise FileNotFoundError(
            "Cannot retrieve last analysis id, you need to provide analysis id explicitly"
        ) from exc

    return analysis_id


def _retrieve_analysis_result(
    retrieve_func: Callable[..., Any], analysis_id: str
) -> Any:
    """Retrieve analysis result, raise error if analysis failed."""
    retries = 0
    while True:
        try:
            return retrieve_func(analysis_id)
        except ApiException as exc:
            if exc.status == 400:
                # Re-raise if the exception is bad request (e.g. analysis did not finish successfully).
                raise

            _LOGGER.debug(
                "Retrieved error response %s from server: %s", exc.status, exc.reason
            )
            response = json.loads(exc.body)

            if "error" in response:
                # Error produced based on API endpoints semantics...
                _LOGGER.debug("Error from Thoth: %s", response)
                _LOGGER.error("%s (analysis: %s)", response["error"], analysis_id)
            else:
                # Other errors (e.g. internal server error).
                _LOGGER.error("Error from Thoth: %s", response)

            if retries >= _RETRY_ON_ERROR_COUNT:
                return None

            retries += 1
            _LOGGER.warning(
                "Retrying in a few moments... (attempt %d/%d)",
                retries,
                _RETRY_ON_ERROR_COUNT,
            )
            sleep(_RETRY_ON_ERROR_SLEEP)


def _get_static_analysis(src_path: str = ".") -> typing.Optional[dict]:
    """Get static analysis of files used in project."""
    # We are running in the root directory of project, use the root part for gathering static analysis.
    _LOGGER.info("Performing static analysis of sources to gather library usage")
    try:
        library_usage = gather_library_usage(
            src_path, ignore_errors=True, without_standard_imports=True
        )
    except FileNotFoundError:
        _LOGGER.warning("No library usage was aggregated - no Python sources found")
        return None

    report = {}  # type: Dict[Any, Any]
    for file_record in library_usage["report"].values():
        for library, usage in file_record.items():
            # We could filter out some of the libraries which were used.
            if library not in report:
                report[library] = set()

            report[library].update(usage)

    return {
        "report": {k: list(v) for k, v in report.items()},
        "version": library_usage["version"],
    }


def _is_s2i() -> bool:
    """Check if we run in an OpenShift s2i build."""
    # This environment variable is used by OpenShift's s2i build process.
    return "STI_SCRIPTS_PATH" in os.environ


def _get_origin() -> typing.Optional[str]:
    """Check git origin configured."""
    result = run_command("git config --get remote.origin.url", raise_on_error=False)
    if result.return_code != 0:
        _LOGGER.debug(
            "Failed to obtain information about git origin: %s", result.stderr
        )
        return None

    origin = result.stdout.strip()
    if origin:
        _LOGGER.debug("Found git origin %r", origin)
        return origin

    return None


def advise_using_config(
    pipfile: str,
    pipfile_lock: str,
    config: str = None,
    *,
    runtime_environment_name: typing.Optional[str] = None,
    src_path: typing.Optional[str] = None,
    recommendation_type: str = None,
    dev: bool = False,
    no_static_analysis: bool = False,
    no_user_stack: bool = False,
    nowait: bool = False,
    force: bool = False,
    limit: int = None,
    count: int = 1,
    debug: bool = False,
    origin: str = None,
    github_event_type: typing.Optional[str] = None,
    github_check_run_id: typing.Optional[int] = None,
    github_installation_id: typing.Optional[int] = None,
    github_base_repo_url: typing.Optional[str] = None,
    source_type: typing.Optional[ThothAdviserIntegrationEnum] = None,
) -> typing.Optional[typing.Tuple[typing.Dict[str, typing.Any], bool]]:
    """Trigger advise, respecting the configuration file supplied directly as a string or as a file path."""
    try:
        thoth_config.load_config_from_file(config)
    except (FileNotFoundError, IOError):
        thoth_config.load_config_from_string(config)

    return advise(
        pipfile=pipfile,
        pipfile_lock=pipfile_lock,
        recommendation_type=recommendation_type,
        src_path=src_path if src_path is not None else thoth_config.config_path,
        runtime_environment=thoth_config.get_runtime_environment(
            runtime_environment_name
        ),
        runtime_environment_name=runtime_environment_name,
        dev=dev,
        no_static_analysis=no_static_analysis,
        no_user_stack=no_user_stack,
        nowait=nowait,
        force=force,
        limit=limit,
        count=count,
        debug=debug,
        origin=origin,
        github_event_type=github_event_type,
        github_check_run_id=github_check_run_id,
        github_installation_id=github_installation_id,
        github_base_repo_url=github_base_repo_url,
        source_type=source_type,
    )


@with_api_client
def advise(
    api_client: ApiClient,
    pipfile: str,
    pipfile_lock: str,
    recommendation_type: str = None,
    *,
    runtime_environment: dict = None,
    src_path: str = ".",
    runtime_environment_name: str = None,
    dev: bool = False,
    no_static_analysis: bool = False,
    no_user_stack: bool = False,
    nowait: bool = False,
    force: bool = False,
    limit: int = None,
    count: int = 1,
    debug: bool = False,
    origin: str = None,
    github_event_type: typing.Optional[str] = None,
    github_check_run_id: typing.Optional[int] = None,
    github_installation_id: typing.Optional[int] = None,
    github_base_repo_url: typing.Optional[str] = None,
    source_type: typing.Optional[ThothAdviserIntegrationEnum] = None,
) -> typing.Optional[tuple]:
    """Submit a stack for adviser checks and wait for results."""
    if not pipfile:
        raise ValueError("No Pipfile content provided for advises")

    if runtime_environment is None:
        runtime_environment = (
            thoth_config.get_runtime_environment(runtime_environment_name) or dict()
        )

    if runtime_environment_name is None and runtime_environment:
        runtime_environment_name = runtime_environment.get("name")

    if (runtime_environment and runtime_environment_name) and runtime_environment.get(
        "name"
    ) != runtime_environment_name:
        raise ValueError(
            "Runtime environment name supplied does not match with the one stated in the config file"
        )

    if recommendation_type is None:
        priority = (
            runtime_environment.pop("recommendation_type", None),
            thoth_config.content.get("recommendation_type", None),
            "stable",
        )
        recommendation_type = next(filter(bool, priority))

    if no_user_stack and pipfile_lock:
        _LOGGER.warning(
            "The user stack found in the lock file will not be supplied as requested"
        )
        pipfile_lock = ""

    library_usage = None
    if not no_static_analysis:
        library_usage = _get_static_analysis(src_path)
        _LOGGER.debug(
            "Library usage:%s",
            "\n" + json.dumps(library_usage, indent=2) if library_usage else None,
        )

    stack = PythonStack(requirements=pipfile, requirements_lock=pipfile_lock or "")

    if runtime_environment:
        # Override recommendation type specified explicitly in the runtime environment entry.
        runtime_environment.pop("recommendation_type", None)

    advise_input = AdviseInput(
        stack, runtime_environment=runtime_environment, library_usage=library_usage
    )
    api_instance = AdviseApi(api_client)

    if recommendation_type:
        recommendation_type = recommendation_type.lower()

    if source_type is None and _is_s2i():
        source_type = ThothAdviserIntegrationEnum.S2I

    parameters = {
        "recommendation_type": recommendation_type,
        "debug": debug,
        "force": force,
        "source_type": source_type.name.lower() if source_type is not None else None,
        "origin": _get_origin(),
        "dev": dev,
    }  # type: Dict[str, Any]

    if limit is not None:
        parameters["limit"] = limit

    if count is not None:
        parameters["count"] = count

    if origin is not None:
        parameters["origin"] = origin

    if github_event_type is not None:
        parameters["github_event_type"] = github_event_type

    if github_check_run_id is not None:
        parameters["github_check_run_id"] = github_check_run_id

    if github_installation_id is not None:
        parameters["github_installation_id"] = github_installation_id

    if github_base_repo_url is not None:
        parameters["github_base_repo_url"] = github_base_repo_url

    response = api_instance.post_advise_python(advise_input, **parameters)

    _LOGGER.info(
        "Successfully submitted advise analysis %r to %r",
        response.analysis_id,
        thoth_config.api_url,
    )

    _note_last_analysis_id(response.analysis_id)

    _LOGGER.debug("Analysis parameters:\n%r", pprint.pformat(parameters))
    _LOGGER.debug("Adviser input:\n%s", advise_input.to_str())

    if nowait:
        return response.analysis_id
    # We call custom status function for advise until swagger client supports mulitple response codes.
    _wait_for_analysis(is_analysis_ready, response.analysis_id)
    _LOGGER.debug("Retrieving adviser result for %r", response.analysis_id)
    response = _retrieve_analysis_result(
        api_instance.get_advise_python, response.analysis_id
    )
    if not response:
        return None

    _LOGGER.debug("Adviser check metadata: %r", response.metadata)

    return response.result, response.result["error"]


def advise_here(
    recommendation_type: typing.Optional[str] = None,
    *,
    runtime_environment: dict = None,
    src_path: str = ".",
    runtime_environment_name: typing.Optional[str] = None,
    dev: bool = False,
    no_static_analysis: bool = False,
    no_user_stack: bool = False,
    nowait: bool = False,
    force: bool = False,
    limit: typing.Optional[int] = None,
    count: int = 1,
    debug: bool = False,
    origin: typing.Optional[str] = None,
    github_event_type: typing.Optional[str] = None,
    github_check_run_id: typing.Optional[int] = None,
    github_installation_id: typing.Optional[int] = None,
    github_base_repo_url: typing.Optional[str] = None,
    source_type: typing.Optional[ThothAdviserIntegrationEnum] = None,
) -> typing.Optional[tuple]:
    """Run advise in current directory, requires no arguments."""
    requirements_format = thoth_config.requirements_format
    if requirements_format == "pipenv":
        _LOGGER.info(
            "Using Pipenv files to manage dependencies located in %r", os.getcwd()
        )
        pipfile_lock_exists = os.path.exists("Pipfile.lock")

        if pipfile_lock_exists:
            _LOGGER.info(
                "Submitting Pipfile.lock as a base for user's stack scoring - see %s",
                jl("user_stack"),
            )

        project = Project.from_files(
            without_pipfile_lock=not os.path.exists("Pipfile.lock")
        )

        if (
            pipfile_lock_exists
            and project.pipfile_lock.meta.hash["sha256"]
            != project.pipfile.hash()["sha256"]
        ):
            _LOGGER.error(
                "Pipfile hash stated in Pipfile.lock %r does not correspond to Pipfile hash %r - was Pipfile "
                "adjusted? This error is not critical.",
                project.pipfile_lock.meta.hash["sha256"][:6],
                project.pipfile.hash()["sha256"][:6],
            )
    elif requirements_format in ("pip", "pip-tools", "pip-compile"):
        _LOGGER.info(
            "Using requirements.txt file to manage dependencies located in %r",
            os.getcwd(),
        )
        project = Project.from_pip_compile_files(allow_without_lock=True)
    else:
        raise ValueError(
            f"Unknown configuration option for requirements format: {requirements_format!r}"
        )

    pipfile = project.pipfile.to_string()
    pipfile_lock_str = project.pipfile_lock.to_string() if project.pipfile_lock else ""

    return advise(
        pipfile=pipfile,
        pipfile_lock=pipfile_lock_str,
        recommendation_type=recommendation_type,
        src_path=src_path,
        runtime_environment=runtime_environment,
        runtime_environment_name=runtime_environment_name,
        dev=dev,
        no_static_analysis=no_static_analysis,
        no_user_stack=no_user_stack,
        nowait=nowait,
        force=force,
        limit=limit,
        count=count,
        debug=debug,
        origin=origin,
        source_type=source_type,
        github_event_type=github_event_type,
        github_check_run_id=github_check_run_id,
        github_installation_id=github_installation_id,
        github_base_repo_url=github_base_repo_url,
    )


@with_api_client
def provenance_check(
    api_client: ApiClient,
    pipfile: str,
    pipfile_lock: str,
    *,
    nowait: bool = False,
    force: bool = False,
    debug: bool = False,
    origin: str = None,
) -> typing.Optional[tuple]:
    """Submit a stack for provenance checks and wait for results."""
    if not pipfile:
        raise ValueError("No Pipfile content provided for provenance checks")

    stack = PythonStack(requirements=pipfile, requirements_lock=pipfile_lock)
    api_instance = ProvenanceApi(api_client)
    response = api_instance.post_provenance_python(
        stack, debug=debug, force=force, origin=origin
    )
    _LOGGER.info(
        "Successfully submitted provenance check analysis %r to %r",
        response.analysis_id,
        thoth_config.api_url,
    )

    _note_last_analysis_id(response.analysis_id)

    if nowait:
        return response.analysis_id

    _wait_for_analysis(is_analysis_ready, response.analysis_id)
    _LOGGER.debug("Retrieving provenance check result for %r", response.analysis_id)
    response = _retrieve_analysis_result(
        api_instance.get_provenance_python, response.analysis_id
    )
    if not response:
        return None

    _LOGGER.debug("Provenance check metadata: %r", response.metadata)
    return response.result["report"], response.result["error"]


def provenance_check_here(
    *,
    nowait: bool = False,
    force: bool = False,
    debug: bool = False,
    origin: str = None,
) -> typing.Optional[tuple]:
    """Submit a provenance check in current directory."""
    if not os.path.isfile("Pipfile"):
        raise FileNotFoundError("No Pipfile found in current directory")

    if not os.path.isfile("Pipfile.lock"):
        raise FileNotFoundError("No Pipfile.lock found in current directory")

    with open("Pipfile", "r") as pipfile, open("Pipfile.lock", "r") as piplock:
        return provenance_check(
            pipfile.read(),
            piplock.read(),
            nowait=nowait,
            force=force,
            debug=debug,
            origin=origin,
        )


@with_api_client
def image_analysis(
    api_client: ApiClient,
    image: str,
    *,
    environment_type: str,
    registry_user: str = None,
    registry_password: str = None,
    verify_tls: bool = True,
    nowait: bool = False,
    force: bool = False,
    debug: bool = False,
) -> Union[Dict, str, None]:
    """Submit an image for analysis to Thoth."""
    if not image:
        raise ValueError("No image provided")

    api_instance = ImageAnalysisApi(api_client)
    if registry_user or registry_password:
        # Swagger client handles None in a different way - we need to explicitly avoid passing
        # registry user and registry password if they are not set.
        response = api_instance.post_analyze(
            image=image,
            debug=debug,
            registry_user=registry_user,
            registry_password=registry_password,
            verify_tls=verify_tls,
            force=force,
            environment_type=environment_type,
        )
    else:
        response = api_instance.post_analyze(
            image=image, debug=debug, verify_tls=verify_tls, force=force
        )

    _LOGGER.info(
        "Successfully submitted provenance check analysis %r to %r",
        response.analysis_id,
        thoth_config.api_url,
    )
    if nowait:
        return response.analysis_id

    _wait_for_analysis(is_analysis_ready, response.analysis_id)
    _LOGGER.debug(
        "Retrieving image analysis result result for %r", response.analysis_id
    )
    response = _retrieve_analysis_result(api_instance.get_analyze, response.analysis_id)
    if not response:
        return None

    _LOGGER.debug("Image analysis metadata: %r", response.metadata)
    return response.result


@with_api_client
def build_analysis(
    api_client: ApiClient,
    build_log: dict,
    base_image: str,
    output_image: str,
    *,
    environment_type: str,
    base_registry_user: typing.Optional[str] = None,
    base_registry_password: typing.Optional[str] = None,
    base_registry_verify_tls: bool = True,
    output_registry_user: typing.Optional[str] = None,
    output_registry_password: typing.Optional[str] = None,
    output_registry_verify_tls: bool = True,
    origin: typing.Optional[str] = None,
    nowait: bool = False,
    force: bool = False,
    debug: bool = False,
) -> typing.Union[typing.Dict, str]:
    """Submit a build image and logs for analysis to Thoth."""
    if build_log or base_image or output_image:
        build_detail = {
            "build_log": build_log,
            "base_image": base_image,
            "output_image": output_image,
        }
    else:
        raise ValueError("No build info provided")

    params = dict(
        body=build_detail,
        base_registry_user=base_registry_user,
        base_registry_password=base_registry_password,
        base_registry_verify_tls=base_registry_verify_tls,
        output_registry_user=output_registry_user,
        output_registry_password=output_registry_password,
        output_registry_verify_tls=output_registry_verify_tls,
        environment_type=environment_type,
        origin=origin,
        debug=debug,
        force=force,
    )

    # Swagger client handles None in a different way - we need to explicitly avoid passing
    # values that are not present.
    params = {k: v for k, v in params.items() if v is not None}

    api_instance = BuildAnalysisApi(api_client)
    response = api_instance.post_build(**params)

    _LOGGER.info("Successfully submitted build analysis to %r", thoth_config.api_url)
    _LOGGER.debug("Build analysis parameters: %r", params)
    if nowait:
        return response

    return response


@with_api_client
def get_log(api_client: ApiClient, analysis_id: str = None):
    """Get log of an analysis - the analysis type and endpoint are automatically derived from analysis id.

    If analysis_id is not provided, its get from the last thamos call which stores it in a temporary file.
    """
    if not analysis_id:
        analysis_id = _get_last_analysis_id()

    if analysis_id.startswith("package-extract-"):
        api_instance = ImageAnalysisApi(
            api_client
        )  # type: Union[ImageAnalysisApi, ProvenanceApi, AdviseApi]
        method = api_instance.get_analyze_log  # type: ignore
    elif analysis_id.startswith("provenance-checker-"):
        api_instance = ProvenanceApi(api_client)
        method = api_instance.get_provenance_python_log  # type: ignore
    elif analysis_id.startswith("adviser-"):
        api_instance = AdviseApi(api_client)
        method = api_instance.get_advise_python_log  # type: ignore
    else:
        raise UnknownAnalysisType(
            "Cannot determine analysis type from identifier: %r", analysis_id
        )

    json_log = method(analysis_id).log

    if not json_log:
        return json_log

    result = ""
    for line in json_log.splitlines():
        try:
            content = json.loads(line)
            if not int(os.getenv("THAMOS_NO_EMOJI", 0)):
                if content["levelname"] == "DEBUG":
                    message = colored(content["message"], "green")
                elif content["levelname"] == "INFO":
                    message = colored(content["message"], "cyan")
                elif content["levelname"] == "WARNING":
                    message = colored(content["message"], "yellow", attrs=["bold"])
                elif content["levelname"] in ("ERROR", "CRITICAL"):
                    message = colored(content["message"], "red", attrs=["bold"])
                else:
                    message = content["message"]

                result += "{} {:<27} {}: {}\n".format(
                    content["asctime"], content["name"], content["levelname"], message
                )
            else:
                result += "{} {:<27} {}: {}\n".format(
                    content["asctime"],
                    content["name"],
                    content["levelname"],
                    content["message"],
                )
        except Exception:
            # If the content parsed does not carry logger information or has not relevant
            # entries, log the original message.
            result += line + "\n"
            continue

    return result


@with_api_client
def get_status(api_client: ApiClient, analysis_id: str = None):
    """Get status of an analysis - the analysis type and endpoint are automatically derived from analysis id.

    If analysis_id is not provided, its get from the last thamos call which stores it in a temporary file.
    """
    if not analysis_id:
        analysis_id = _get_last_analysis_id()

    if analysis_id.startswith("package-extract-"):
        api_instance = ImageAnalysisApi(
            api_client
        )  # type: Union[ImageAnalysisApi, ProvenanceApi, AdviseApi]
        method = api_instance.get_analyze_status  # type: ignore
    elif analysis_id.startswith("provenance-checker-"):
        api_instance = ProvenanceApi(api_client)
        method = api_instance.get_provenance_python_status  # type: ignore
    elif analysis_id.startswith("adviser-"):
        api_instance = AdviseApi(api_client)
        method = api_instance.get_advise_python_status  # type: ignore
    else:
        raise UnknownAnalysisType(
            "Cannot determine analysis type from identifier: %r", analysis_id
        )

    return method(analysis_id).status.to_dict()


@with_api_client
def get_analysis_results(api_client: ApiClient, analysis_id: str):
    """Get the analysis result from a given id."""
    if analysis_id.startswith("package-extract-"):
        api_instance = ImageAnalysisApi(
            api_client
        )  # type: Union[ImageAnalysisApi, ProvenanceApi, AdviseApi]
        method = api_instance.get_analyze  # type: ignore
        response = _retrieve_analysis_result(
            method, analysis_id
        )  # type: AnalysisResultResponse
        return response.result
    elif analysis_id.startswith("provenance-checker-"):
        api_instance = ProvenanceApi(api_client)
        method = api_instance.get_provenance_python  # type: ignore
        response = _retrieve_analysis_result(method, analysis_id)
        return response.result["report"], response.result["error"]
    elif analysis_id.startswith("adviser-"):
        api_instance = AdviseApi(api_client)
        method = api_instance.get_advise_python  # type: ignore
        response = _retrieve_analysis_result(method, analysis_id)
        return response.result, response.result["error"]
    else:
        raise UnknownAnalysisType(
            "Cannot determine analysis type from identifier: %r", analysis_id
        )


def install_using_config(
    config: str,
    runtime_environment_name: typing.Optional[str] = None,
    dev: bool = False,
) -> None:
    """Perform installation given the configuration supplied."""
    try:
        thoth_config.load_config_from_file(config)
    except (FileNotFoundError, IOError):
        thoth_config.load_config_from_string(config)

    install(runtime_environment_name=runtime_environment_name, dev=dev)


def install(
    runtime_environment_name: typing.Optional[str] = None,
    dev: bool = False,
    pip_args: typing.Optional[typing.Tuple[str]] = None,
) -> None:
    """Perform installation of packages for the given runtime environment.

    If the runtime environment is not specified, the first environment stated in the configuration is used.
    """
    method = (
        "pipenv" if thoth_config.requirements_format == "pipenv" else "requirements"
    )

    if not dev and method == "pipenv":
        _LOGGER.warning(
            "Development dependencies will not be installed - see %s", jl("no_dev")
        )

    with cwd(thoth_config.get_overlays_directory(runtime_environment_name)):
        if method == "pipenv":
            if not os.path.isfile("Pipfile.lock"):
                raise NoRequirementsFile(
                    f"No Pipfile.lock found in {os.getcwd()!r} needed to install dependencies, "
                    "issue `thamos advise` resolve dpeendencies"
                )
            if not os.path.isfile("Pipfile"):  # Required for computing digests.
                raise NoRequirementsFile(
                    f"No Pipfile found in {os.getcwd()!r} needed for the installation process"
                )

            if dev:
                with open("Pipfile.lock") as pipfile_lock_file:
                    content = json.load(pipfile_lock_file)

                if not content.get("develop"):
                    raise NoDevRequirements(
                        "No development requirements found in the lock file, make sure development "
                        "requirements are stated and the resolved stack preserves them by "
                        "using `thamos advise --dev`"
                    )

                del content
        else:
            if not os.path.isfile("requirements.txt"):
                raise NoRequirementsFile(
                    f"No requirements.txt file found in {os.getcwd()!r} needed to install dependencies"
                )

        if runtime_environment_name is None:
            config_entry = thoth_config.get_runtime_environment(runtime_environment_name)
            runtime_environment_name = config_entry["name"]
        _LOGGER.info("Installing requirements for runtime environment %r", runtime_environment_name)

        _LOGGER.info(
            "Using %r installation method to install dependencies stated in %r",
            method,
            os.getcwd(),
        )

        micropipenv_kwargs = {
            "method": method,
            "deploy": True,
            "dev": dev,
            "pip_args": pip_args,
        }

        virtualenv_path = thoth_config.get_virtualenv_path(runtime_environment_name)
        if virtualenv_path:
            if not os.path.isdir(virtualenv_path):
                thoth_config.create_virtualenv()

            micropipenv_kwargs["pip_bin"] = os.path.join(virtualenv_path, "bin", "pip3")

        # micropipenv writes and prints the lockfile which is not very user friendly when thamos is used by a user.
        # Suppress this behavior unless these environment variables options are supplied explicitly.
        old_write = os.getenv("MICROPIPENV_NO_LOCKFILE_WRITE")
        if old_write is None:
            os.environ["MICROPIPENV_NO_LOCKFILE_WRITE"] = "1"

        old_print = os.getenv("MICROPIPENV_NO_LOCKFILE_PRINT")
        if old_print is None:
            os.environ["MICROPIPENV_NO_LOCKFILE_PRINT"] = "1"

        try:
            micropipenv.install(**micropipenv_kwargs)
        finally:
            if old_write is None:
                os.environ.pop("MICROPIPENV_NO_LOCKFILE_WRITE", None)

            if old_print is None:
                os.environ.pop("MICROPIPENV_NO_LOCKFILE_PRINT", None)


@with_api_client
def list_hardware_environments(api_client: ApiClient) -> typing.Dict[str, Any]:
    """Get information about hardware for which Thoth can give recommendations."""
    return (
        HardwareApi(api_client)
        .list_hardware_environments()
        .to_dict()["hardware_environments"]
    )


@with_api_client
def list_thoth_s2i(api_client: ApiClient) -> typing.Dict[str, Any]:
    """Get information about hardware for which Thoth can give recommendations."""
    return S2iApi(api_client).list_s2i_python().to_dict()["s2i"]


@with_api_client
def list_python_package_indexes(api_client: ApiClient) -> typing.Dict[str, Any]:
    """Get information about hardware for which Thoth can give recommendations."""
    return (
        PythonPackagesApi(api_client).list_python_package_indexes().to_dict()["indexes"]
    )



#!/usr/bin/env python3
#
# Copyright(C) 2020 Red Hat, Thoth Team
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""Thoth AIDevSecOps Tutorial App."""

import os
import logging

from version import __version__

from flask_cors import CORS
from flask import Flask
from flask import request
from flask import redirect

from prometheus_flask_exporter import PrometheusMetrics
from prometheus_client import generate_latest

import numpy as np

from src.model import Model

_LOGGER = logging.getLogger("aidevsecops-tutorial")
_LOGGER.info("Thoth AIDevSecOps Tutorial v%s", __version__)

_GRAFANA_REDIRECT_URL = os.getenv(
    "THOTH_AIDEVSECOPS_GRAFANA_REDIRECT_URL",
    "https://github.com/thoth-station/elyra-aidevsecops-tutorial/blob/master/README.md",
)

application = Flask("aidevsecops-tutorial")

# Add Cross Origin Request Policy to all
CORS(application)

prometheus_metrics = PrometheusMetrics(application, group_by="endpoint")

# static information as metric
prometheus_metrics.info(
    "aidevsecops_tutorial_app_info", "App version deployed", version=__version__
)

model = Model()

# custom metric to expose model version
model_version_metric = prometheus_metrics.info(
    "aidevsecops_tutorial_model_info",
    "Model version deployed",
    version=model.model_version,  # label
)


@application.before_first_request
def before_first_request_callback():
    """Register callback, runs before first request to this service."""
    model_version_metric.set(1)
    _LOGGER.info("Running once before first request to expose metric.")


@application.after_request
def extend_response_headers(response):
    """Just add my signature."""
    response.headers["X-Thoth-AIDevSecOps-Tutorial-Version"] = f"v{__version__}"
    return response


@application.route("/")
def main():
    """Show this to humans."""
    return redirect(_GRAFANA_REDIRECT_URL, code=308)


@application.route("/predict", methods=["POST"])
def predict():
    """Evaluate prediction."""
    image_list = request.get_json()["inputs"]

    # reshape
    image_array = np.array(image_list)

    prediction, probability = model.predict(image_array=image_array)
    return {
        "response": f"The number in the image is {str(prediction)}"
        f" with probability {str(probability)}"
    }


@application.route("/metrics")
def metrics():
    """Return the Prometheus Metrics."""
    return generate_latest().decode("utf-8")


if __name__ == "__main__":
    _LOGGER.debug("Debug mode is on")
    application.run(host="0.0.0.0", port=8080)



# coding: utf-8

# flake8: noqa
"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from thamos.swagger_client.models.advise_input import AdviseInput
from thamos.swagger_client.models.advise_input_library_usage import (
    AdviseInputLibraryUsage,
)
from thamos.swagger_client.models.analysis_listing_response import (
    AnalysisListingResponse,
)
from thamos.swagger_client.models.analysis_log_response import AnalysisLogResponse
from thamos.swagger_client.models.analysis_response import AnalysisResponse
from thamos.swagger_client.models.analysis_response_error import AnalysisResponseError
from thamos.swagger_client.models.analysis_result_response import AnalysisResultResponse
from thamos.swagger_client.models.analysis_result_response_metadata import (
    AnalysisResultResponseMetadata,
)
from thamos.swagger_client.models.analysis_result_response_metadata_distribution import (
    AnalysisResultResponseMetadataDistribution,
)
from thamos.swagger_client.models.analysis_result_response_metadata_distribution_version_parts import (
    AnalysisResultResponseMetadataDistributionVersionParts,
)
from thamos.swagger_client.models.analysis_result_response_metadata_python import (
    AnalysisResultResponseMetadataPython,
)
from thamos.swagger_client.models.analysis_status_response import AnalysisStatusResponse
from thamos.swagger_client.models.analysis_status_response_status import (
    AnalysisStatusResponseStatus,
)
from thamos.swagger_client.models.build import Build
from thamos.swagger_client.models.build_analysis_response import BuildAnalysisResponse
from thamos.swagger_client.models.build_analysis_response_base_image_analysis import (
    BuildAnalysisResponseBaseImageAnalysis,
)
from thamos.swagger_client.models.build_analysis_response_error import (
    BuildAnalysisResponseError,
)
from thamos.swagger_client.models.build_analysis_response_error_base_image_analysis import (
    BuildAnalysisResponseErrorBaseImageAnalysis,
)
from thamos.swagger_client.models.build_build_log import BuildBuildLog
from thamos.swagger_client.models.image_metadata_response import ImageMetadataResponse
from thamos.swagger_client.models.inline_response200 import InlineResponse200
from thamos.swagger_client.models.inline_response200_hardware_environments import (
    InlineResponse200HardwareEnvironments,
)
from thamos.swagger_client.models.inline_response200_parameters import (
    InlineResponse200Parameters,
)
from thamos.swagger_client.models.kebechet_webhook_input import KebechetWebhookInput
from thamos.swagger_client.models.log import Log
from thamos.swagger_client.models.python_package_dependencies import (
    PythonPackageDependencies,
)
from thamos.swagger_client.models.python_package_dependencies_dependencies import (
    PythonPackageDependenciesDependencies,
)
from thamos.swagger_client.models.python_package_dependencies_error import (
    PythonPackageDependenciesError,
)
from thamos.swagger_client.models.python_package_indexes import PythonPackageIndexes
from thamos.swagger_client.models.python_package_indexes_indexes import (
    PythonPackageIndexesIndexes,
)
from thamos.swagger_client.models.python_package_metadata_response import (
    PythonPackageMetadataResponse,
)
from thamos.swagger_client.models.python_package_metadata_response_error import (
    PythonPackageMetadataResponseError,
)
from thamos.swagger_client.models.python_package_metadata_response_metadata import (
    PythonPackageMetadataResponseMetadata,
)
from thamos.swagger_client.models.python_package_versions_response import (
    PythonPackageVersionsResponse,
)
from thamos.swagger_client.models.python_package_versions_response_error import (
    PythonPackageVersionsResponseError,
)
from thamos.swagger_client.models.python_package_versions_response_versions import (
    PythonPackageVersionsResponseVersions,
)
from thamos.swagger_client.models.python_platforms import PythonPlatforms
from thamos.swagger_client.models.python_stack import PythonStack
from thamos.swagger_client.models.qeb_hwt_thamos_advise_input import (
    QebHwtThamosAdviseInput,
)
from thamos.swagger_client.models.runtime_environment import RuntimeEnvironment
from thamos.swagger_client.models.s2_i_python_response import S2IPythonResponse
from thamos.swagger_client.models.s2_i_python_response_s2i import S2IPythonResponseS2i



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class InlineResponse200HardwareEnvironments(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "cpu_cores": "int",
        "cpu_family": "int",
        "cpu_model": "int",
        "cpu_model_name": "str",
        "cpu_physical_cpus": "int",
        "cpu_vendor": "int",
        "gpu_cores": "int",
        "gpu_memory_size": "int",
        "gpu_model_name": "str",
        "gpu_vendor": "str",
        "ram_size": "int",
    }

    attribute_map = {
        "cpu_cores": "cpu_cores",
        "cpu_family": "cpu_family",
        "cpu_model": "cpu_model",
        "cpu_model_name": "cpu_model_name",
        "cpu_physical_cpus": "cpu_physical_cpus",
        "cpu_vendor": "cpu_vendor",
        "gpu_cores": "gpu_cores",
        "gpu_memory_size": "gpu_memory_size",
        "gpu_model_name": "gpu_model_name",
        "gpu_vendor": "gpu_vendor",
        "ram_size": "ram_size",
    }

    def __init__(
        self,
        cpu_cores=None,
        cpu_family=None,
        cpu_model=None,
        cpu_model_name=None,
        cpu_physical_cpus=None,
        cpu_vendor=None,
        gpu_cores=None,
        gpu_memory_size=None,
        gpu_model_name=None,
        gpu_vendor=None,
        ram_size=None,
    ):  # noqa: E501
        """InlineResponse200HardwareEnvironments - a model defined in Swagger"""  # noqa: E501
        self._cpu_cores = None
        self._cpu_family = None
        self._cpu_model = None
        self._cpu_model_name = None
        self._cpu_physical_cpus = None
        self._cpu_vendor = None
        self._gpu_cores = None
        self._gpu_memory_size = None
        self._gpu_model_name = None
        self._gpu_vendor = None
        self._ram_size = None
        self.discriminator = None
        if cpu_cores is not None:
            self.cpu_cores = cpu_cores
        if cpu_family is not None:
            self.cpu_family = cpu_family
        if cpu_model is not None:
            self.cpu_model = cpu_model
        if cpu_model_name is not None:
            self.cpu_model_name = cpu_model_name
        if cpu_physical_cpus is not None:
            self.cpu_physical_cpus = cpu_physical_cpus
        if cpu_vendor is not None:
            self.cpu_vendor = cpu_vendor
        if gpu_cores is not None:
            self.gpu_cores = gpu_cores
        if gpu_memory_size is not None:
            self.gpu_memory_size = gpu_memory_size
        if gpu_model_name is not None:
            self.gpu_model_name = gpu_model_name
        if gpu_vendor is not None:
            self.gpu_vendor = gpu_vendor
        if ram_size is not None:
            self.ram_size = ram_size

    @property
    def cpu_cores(self):
        """Gets the cpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501

        Number of cores of the CPU.  # noqa: E501

        :return: The cpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._cpu_cores

    @cpu_cores.setter
    def cpu_cores(self, cpu_cores):
        """Sets the cpu_cores of this InlineResponse200HardwareEnvironments.

        Number of cores of the CPU.  # noqa: E501

        :param cpu_cores: The cpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._cpu_cores = cpu_cores

    @property
    def cpu_family(self):
        """Gets the cpu_family of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The CPU family.  # noqa: E501

        :return: The cpu_family of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._cpu_family

    @cpu_family.setter
    def cpu_family(self, cpu_family):
        """Sets the cpu_family of this InlineResponse200HardwareEnvironments.

        The CPU family.  # noqa: E501

        :param cpu_family: The cpu_family of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._cpu_family = cpu_family

    @property
    def cpu_model(self):
        """Gets the cpu_model of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The CPU model.  # noqa: E501

        :return: The cpu_model of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this InlineResponse200HardwareEnvironments.

        The CPU model.  # noqa: E501

        :param cpu_model: The cpu_model of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._cpu_model = cpu_model

    @property
    def cpu_model_name(self):
        """Gets the cpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The CPU model name.  # noqa: E501

        :return: The cpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model_name

    @cpu_model_name.setter
    def cpu_model_name(self, cpu_model_name):
        """Sets the cpu_model_name of this InlineResponse200HardwareEnvironments.

        The CPU model name.  # noqa: E501

        :param cpu_model_name: The cpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: str
        """

        self._cpu_model_name = cpu_model_name

    @property
    def cpu_physical_cpus(self):
        """Gets the cpu_physical_cpus of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The CPU physical CPUs.  # noqa: E501

        :return: The cpu_physical_cpus of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._cpu_physical_cpus

    @cpu_physical_cpus.setter
    def cpu_physical_cpus(self, cpu_physical_cpus):
        """Sets the cpu_physical_cpus of this InlineResponse200HardwareEnvironments.

        The CPU physical CPUs.  # noqa: E501

        :param cpu_physical_cpus: The cpu_physical_cpus of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._cpu_physical_cpus = cpu_physical_cpus

    @property
    def cpu_vendor(self):
        """Gets the cpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The CPU vendor.  # noqa: E501

        :return: The cpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._cpu_vendor

    @cpu_vendor.setter
    def cpu_vendor(self, cpu_vendor):
        """Sets the cpu_vendor of this InlineResponse200HardwareEnvironments.

        The CPU vendor.  # noqa: E501

        :param cpu_vendor: The cpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._cpu_vendor = cpu_vendor

    @property
    def gpu_cores(self):
        """Gets the gpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501

        Number of cores of the GPU.  # noqa: E501

        :return: The gpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._gpu_cores

    @gpu_cores.setter
    def gpu_cores(self, gpu_cores):
        """Sets the gpu_cores of this InlineResponse200HardwareEnvironments.

        Number of cores of the GPU.  # noqa: E501

        :param gpu_cores: The gpu_cores of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._gpu_cores = gpu_cores

    @property
    def gpu_memory_size(self):
        """Gets the gpu_memory_size of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The GPU memory size.  # noqa: E501

        :return: The gpu_memory_size of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._gpu_memory_size

    @gpu_memory_size.setter
    def gpu_memory_size(self, gpu_memory_size):
        """Sets the gpu_memory_size of this InlineResponse200HardwareEnvironments.

        The GPU memory size.  # noqa: E501

        :param gpu_memory_size: The gpu_memory_size of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._gpu_memory_size = gpu_memory_size

    @property
    def gpu_model_name(self):
        """Gets the gpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The GPU model name.  # noqa: E501

        :return: The gpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model_name

    @gpu_model_name.setter
    def gpu_model_name(self, gpu_model_name):
        """Sets the gpu_model_name of this InlineResponse200HardwareEnvironments.

        The GPU model name.  # noqa: E501

        :param gpu_model_name: The gpu_model_name of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: str
        """

        self._gpu_model_name = gpu_model_name

    @property
    def gpu_vendor(self):
        """Gets the gpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The GPU vendor.  # noqa: E501

        :return: The gpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._gpu_vendor

    @gpu_vendor.setter
    def gpu_vendor(self, gpu_vendor):
        """Sets the gpu_vendor of this InlineResponse200HardwareEnvironments.

        The GPU vendor.  # noqa: E501

        :param gpu_vendor: The gpu_vendor of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: str
        """

        self._gpu_vendor = gpu_vendor

    @property
    def ram_size(self):
        """Gets the ram_size of this InlineResponse200HardwareEnvironments.  # noqa: E501

        The RAM size.  # noqa: E501

        :return: The ram_size of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :rtype: int
        """
        return self._ram_size

    @ram_size.setter
    def ram_size(self, ram_size):
        """Sets the ram_size of this InlineResponse200HardwareEnvironments.

        The RAM size.  # noqa: E501

        :param ram_size: The ram_size of this InlineResponse200HardwareEnvironments.  # noqa: E501
        :type: int
        """

        self._ram_size = ram_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(InlineResponse200HardwareEnvironments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200HardwareEnvironments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""This file sets up the thoth-thamos module."""

import os
import sys
from setuptools import setup, find_packages
from pathlib import Path
from setuptools.command.test import test as TestCommand  # noqa


def get_install_requires():
    """Get thamos installation requirements."""
    with open("requirements.txt", "r") as requirements_file:
        return [req for req in requirements_file.readlines() if req]


def get_version():
    """Get thamos version."""
    with open(os.path.join("thamos", "__init__.py")) as f:
        content = f.readlines()

    for line in content:
        if line.startswith("__version__ ="):
            # dirty, remove trailing and leading chars
            return line.split(" = ")[1][1:-2]
    raise ValueError("No version identifier found")


class Test(TestCommand):
    """Introduce test command to run testsuite using pytest."""

    _IMPLICIT_PYTEST_ARGS = [
        "tests/",
        "--timeout=2",
        "--cov=./thamos",
        "--capture=no",
        "--verbose",
        "-l",
        "-s",
        "-vv",
    ]

    user_options = [("pytest-args=", "a", "Arguments to pass into py.test")]

    def initialize_options(self):
        """Initialize cli options."""
        super().initialize_options()
        self.pytest_args = None

    def finalize_options(self):
        """Finalize cli options."""
        super().finalize_options()
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        """Run pytests."""
        import pytest  # noqa

        passed_args = list(self._IMPLICIT_PYTEST_ARGS)

        if self.pytest_args:
            self.pytest_args = [arg for arg in self.pytest_args.split() if arg]
            passed_args.extend(self.pytest_args)

        sys.exit(pytest.main(passed_args))


VERSION = get_version()
setup(
    name="thamos",
    entry_points={"console_scripts": ["thamos=thamos.cli:cli"]},
    version=VERSION,
    package_data={"thamos": [os.path.join("data", "*.yaml")]},
    include_package_data=True,
    description="A CLI tool and library for interacting with Thoth",
    long_description=Path("README.rst").read_text(),
    author="Fridolin Pokorny",
    author_email="fridolin@redhat.com",
    license="GPLv3+",
    packages=find_packages(),
    long_description_content_type="text/x-rst",
    cmdclass={"test": Test},
    install_requires=get_install_requires(),
    command_options={
        "build_sphinx": {
            "version": ("setup.py", VERSION),
            "release": ("setup.py", VERSION),
        }
    },
)



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from thamos.swagger_client.api_client import ApiClient


class AdviseApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_advise_python(self, analysis_id, **kwargs):  # noqa: E501
        """Get computed adviser result based on its id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: Advise id returned on advise request. (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_advise_python_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_advise_python_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_advise_python_with_http_info(self, analysis_id, **kwargs):  # noqa: E501
        """Get computed adviser result based on its id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: Advise id returned on advise request. (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_advise_python" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_advise_python`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/advise/python/{analysis_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisResultResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_advise_python_log(self, analysis_id, **kwargs):  # noqa: E501
        """Retrieve a adviser run log.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python_log(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of analysis for which log should be retrieved. (required)
        :return: AnalysisLogResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_advise_python_log_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_advise_python_log_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_advise_python_log_with_http_info(self, analysis_id, **kwargs):  # noqa: E501
        """Retrieve a adviser run log.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python_log_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of analysis for which log should be retrieved. (required)
        :return: AnalysisLogResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_advise_python_log" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_advise_python_log`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/advise/python/{analysis_id}/log",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisLogResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_advise_python_status(self, analysis_id, **kwargs):  # noqa: E501
        """Show status of an adviser computing recommendations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python_status(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested adviser run. (required)
        :return: AnalysisStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_advise_python_status_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_advise_python_status_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_advise_python_status_with_http_info(
        self, analysis_id, **kwargs
    ):  # noqa: E501
        """Show status of an adviser computing recommendations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advise_python_status_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested adviser run. (required)
        :return: AnalysisStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_advise_python_status" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_advise_python_status`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/advise/python/{analysis_id}/status",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisStatusResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_advise_python(self, body, recommendation_type, **kwargs):  # noqa: E501
        """Get advise for Python ecosystem.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_advise_python(body, recommendation_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdviseInput body: Specification of Python application stack with runtime specific information. (required)
        :param str recommendation_type: Recommendation type. (required)
        :param int count: Number of software stacks that should be returned.
        :param int limit: Limit number of software stacks scored.
        :param str origin: A repository where the application stack is used. This is used for tracking as well as for automated reporting when results are available.
        :param str source_type: A flag marking what Thoth integration is requesting adviser:   - cli: Thamos CLI.   - s2i: OpenShift's S2I (Source-to-Image) build.   - github_app: Qeb-Hwt GitHub App.   - kebechet: Kebechet Bot.   - jupyter_notebook: Jupyter Notebook (nb-requirements).
        :param bool dev: Consider or do not consider development dependencies when resolving stacks.
        :param bool debug: Run the given adviser in a verbose mode so developers can debug it.
        :param bool force: Do not use cached results, always run adviser.
        :param str github_event_type: GitHub's event type.
        :param int github_check_run_id: GitHub's event id.
        :param int github_installation_id: GitHub's installation id.
        :param str github_base_repo_url: URL of the GitHub repository containing the Pull Request.
        :return: AnalysisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.post_advise_python_with_http_info(
                body, recommendation_type, **kwargs
            )  # noqa: E501
        else:
            (data) = self.post_advise_python_with_http_info(
                body, recommendation_type, **kwargs
            )  # noqa: E501
            return data

    def post_advise_python_with_http_info(
        self, body, recommendation_type, **kwargs
    ):  # noqa: E501
        """Get advise for Python ecosystem.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_advise_python_with_http_info(body, recommendation_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdviseInput body: Specification of Python application stack with runtime specific information. (required)
        :param str recommendation_type: Recommendation type. (required)
        :param int count: Number of software stacks that should be returned.
        :param int limit: Limit number of software stacks scored.
        :param str origin: A repository where the application stack is used. This is used for tracking as well as for automated reporting when results are available.
        :param str source_type: A flag marking what Thoth integration is requesting adviser:   - cli: Thamos CLI.   - s2i: OpenShift's S2I (Source-to-Image) build.   - github_app: Qeb-Hwt GitHub App.   - kebechet: Kebechet Bot.   - jupyter_notebook: Jupyter Notebook (nb-requirements).
        :param bool dev: Consider or do not consider development dependencies when resolving stacks.
        :param bool debug: Run the given adviser in a verbose mode so developers can debug it.
        :param bool force: Do not use cached results, always run adviser.
        :param str github_event_type: GitHub's event type.
        :param int github_check_run_id: GitHub's event id.
        :param int github_installation_id: GitHub's installation id.
        :param str github_base_repo_url: URL of the GitHub repository containing the Pull Request.
        :return: AnalysisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "body",
            "recommendation_type",
            "count",
            "limit",
            "origin",
            "source_type",
            "dev",
            "debug",
            "force",
            "github_event_type",
            "github_check_run_id",
            "github_installation_id",
            "github_base_repo_url",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_advise_python" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'body' is set
        if "body" not in params or params["body"] is None:
            raise ValueError(
                "Missing the required parameter `body` when calling `post_advise_python`"
            )  # noqa: E501
        # verify the required parameter 'recommendation_type' is set
        if "recommendation_type" not in params or params["recommendation_type"] is None:
            raise ValueError(
                "Missing the required parameter `recommendation_type` when calling `post_advise_python`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "recommendation_type" in params:
            query_params.append(
                ("recommendation_type", params["recommendation_type"])
            )  # noqa: E501
        if "count" in params:
            query_params.append(("count", params["count"]))  # noqa: E501
        if "limit" in params:
            query_params.append(("limit", params["limit"]))  # noqa: E501
        if "origin" in params:
            query_params.append(("origin", params["origin"]))  # noqa: E501
        if "source_type" in params:
            query_params.append(("source_type", params["source_type"]))  # noqa: E501
        if "dev" in params:
            query_params.append(("dev", params["dev"]))  # noqa: E501
        if "debug" in params:
            query_params.append(("debug", params["debug"]))  # noqa: E501
        if "force" in params:
            query_params.append(("force", params["force"]))  # noqa: E501
        if "github_event_type" in params:
            query_params.append(
                ("github_event_type", params["github_event_type"])
            )  # noqa: E501
        if "github_check_run_id" in params:
            query_params.append(
                ("github_check_run_id", params["github_check_run_id"])
            )  # noqa: E501
        if "github_installation_id" in params:
            query_params.append(
                ("github_installation_id", params["github_installation_id"])
            )  # noqa: E501
        if "github_base_repo_url" in params:
            query_params.append(
                ("github_base_repo_url", params["github_base_repo_url"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "body" in params:
            body_params = params["body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/advise/python",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



#!/usr/bin/env python3
"""A simple application to demo Thoth's software stack recommendations."""

import sys
import tensorflow as tf


def thoth_hello():
    """Print hello world from within a TensorFlow session."""
    hello = tf.constant("Hello Thoth by TensorFlow!")
    sess = tf.Session()
    print(sess.run(hello))


if __name__ == "__main__":
    sys.exit(thoth_hello())



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from thamos.swagger_client.api_client import ApiClient


class ImageAnalysisApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_analyze(self, analysis_id, **kwargs):  # noqa: E501
        """Retrieve an analyzer result.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: Id of analysis that results should be retrieved. (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_analyze_with_http_info(analysis_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_analyze_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_analyze_with_http_info(self, analysis_id, **kwargs):  # noqa: E501
        """Retrieve an analyzer result.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: Id of analysis that results should be retrieved. (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_analyze" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_analyze`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/analyze/{analysis_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisResultResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_analyze_by_hash(self, image_hash, **kwargs):  # noqa: E501
        """Retrieve an analyzer result.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_by_hash(image_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_hash: Image hash for identifying image (including hash type, now supported only \"sha256\"). (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_analyze_by_hash_with_http_info(
                image_hash, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_analyze_by_hash_with_http_info(
                image_hash, **kwargs
            )  # noqa: E501
            return data

    def get_analyze_by_hash_with_http_info(self, image_hash, **kwargs):  # noqa: E501
        """Retrieve an analyzer result.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_by_hash_with_http_info(image_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_hash: Image hash for identifying image (including hash type, now supported only \"sha256\"). (required)
        :return: AnalysisResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["image_hash"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_analyze_by_hash" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'image_hash' is set
        if "image_hash" not in params or params["image_hash"] is None:
            raise ValueError(
                "Missing the required parameter `image_hash` when calling `get_analyze_by_hash`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "image_hash" in params:
            path_params["image_hash"] = params["image_hash"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/analyze/by-hash/{image_hash}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisResultResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_analyze_log(self, analysis_id, **kwargs):  # noqa: E501
        """Show logs of an analysis.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_log(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested analysis. (required)
        :return: AnalysisLogResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_analyze_log_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_analyze_log_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_analyze_log_with_http_info(self, analysis_id, **kwargs):  # noqa: E501
        """Show logs of an analysis.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_log_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested analysis. (required)
        :return: AnalysisLogResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_analyze_log" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_analyze_log`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/analyze/{analysis_id}/log",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisLogResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_analyze_status(self, analysis_id, **kwargs):  # noqa: E501
        """Show analysis status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_status(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested analysis. (required)
        :return: AnalysisStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.get_analyze_status_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.get_analyze_status_with_http_info(
                analysis_id, **kwargs
            )  # noqa: E501
            return data

    def get_analyze_status_with_http_info(self, analysis_id, **kwargs):  # noqa: E501
        """Show analysis status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_analyze_status_with_http_info(analysis_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str analysis_id: An id of requested analysis. (required)
        :return: AnalysisStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["analysis_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_analyze_status" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'analysis_id' is set
        if "analysis_id" not in params or params["analysis_id"] is None:
            raise ValueError(
                "Missing the required parameter `analysis_id` when calling `get_analyze_status`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "analysis_id" in params:
            path_params["analysis_id"] = params["analysis_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/analyze/{analysis_id}/status",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisStatusResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_analyze(self, image, **kwargs):  # noqa: E501
        """Analyze the given image asynchronously.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_analyze(image, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image: Name of image - can also specify remote registry to pull image from.  (required)
        :param str registry_user: Registry user to be used for pulling images from registry.
        :param str registry_password: Registry password or token to be used for pulling images from registry.
        :param str environment_type: Type of environment (runtime or buildtime) which is being analyzed.
        :param str origin: A remote where the image is being used. This is used for tracking as well as for automated reporting when results are available.
        :param bool debug: Run the given analyzer in a verbose mode so developers can debug analyzer.
        :param bool verify_tls: Verify TLS certificates of registry from where images are pulled from.
        :param bool force: Do not use cached results, always run analysis.
        :return: AnalysisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.post_analyze_with_http_info(image, **kwargs)  # noqa: E501
        else:
            (data) = self.post_analyze_with_http_info(image, **kwargs)  # noqa: E501
            return data

    def post_analyze_with_http_info(self, image, **kwargs):  # noqa: E501
        """Analyze the given image asynchronously.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_analyze_with_http_info(image, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image: Name of image - can also specify remote registry to pull image from.  (required)
        :param str registry_user: Registry user to be used for pulling images from registry.
        :param str registry_password: Registry password or token to be used for pulling images from registry.
        :param str environment_type: Type of environment (runtime or buildtime) which is being analyzed.
        :param str origin: A remote where the image is being used. This is used for tracking as well as for automated reporting when results are available.
        :param bool debug: Run the given analyzer in a verbose mode so developers can debug analyzer.
        :param bool verify_tls: Verify TLS certificates of registry from where images are pulled from.
        :param bool force: Do not use cached results, always run analysis.
        :return: AnalysisResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "image",
            "registry_user",
            "registry_password",
            "environment_type",
            "origin",
            "debug",
            "verify_tls",
            "force",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_analyze" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'image' is set
        if "image" not in params or params["image"] is None:
            raise ValueError(
                "Missing the required parameter `image` when calling `post_analyze`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "image" in params:
            query_params.append(("image", params["image"]))  # noqa: E501
        if "registry_user" in params:
            query_params.append(
                ("registry_user", params["registry_user"])
            )  # noqa: E501
        if "registry_password" in params:
            query_params.append(
                ("registry_password", params["registry_password"])
            )  # noqa: E501
        if "environment_type" in params:
            query_params.append(
                ("environment_type", params["environment_type"])
            )  # noqa: E501
        if "origin" in params:
            query_params.append(("origin", params["origin"]))  # noqa: E501
        if "debug" in params:
            query_params.append(("debug", params["debug"]))  # noqa: E501
        if "verify_tls" in params:
            query_params.append(("verify_tls", params["verify_tls"]))  # noqa: E501
        if "force" in params:
            query_params.append(("force", params["force"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/analyze",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AnalysisResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_image_metadata(self, image, **kwargs):  # noqa: E501
        """Get metadata for the given image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_image_metadata(image, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image: Name of image - can also specify remote registry to pull image from.  (required)
        :param str registry_user: Registry user to be used for pulling images from registry.
        :param str registry_password: Registry password or token to be used for pulling images from registry.
        :param bool verify_tls: Verify TLS certificates of registry from where images are pulled from.
        :return: ImageMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.post_image_metadata_with_http_info(
                image, **kwargs
            )  # noqa: E501
        else:
            (data) = self.post_image_metadata_with_http_info(
                image, **kwargs
            )  # noqa: E501
            return data

    def post_image_metadata_with_http_info(self, image, **kwargs):  # noqa: E501
        """Get metadata for the given image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_image_metadata_with_http_info(image, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image: Name of image - can also specify remote registry to pull image from.  (required)
        :param str registry_user: Registry user to be used for pulling images from registry.
        :param str registry_password: Registry password or token to be used for pulling images from registry.
        :param bool verify_tls: Verify TLS certificates of registry from where images are pulled from.
        :return: ImageMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "image",
            "registry_user",
            "registry_password",
            "verify_tls",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_image_metadata" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'image' is set
        if "image" not in params or params["image"] is None:
            raise ValueError(
                "Missing the required parameter `image` when calling `post_image_metadata`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "image" in params:
            query_params.append(("image", params["image"]))  # noqa: E501
        if "registry_user" in params:
            query_params.append(
                ("registry_user", params["registry_user"])
            )  # noqa: E501
        if "registry_password" in params:
            query_params.append(
                ("registry_password", params["registry_password"])
            )  # noqa: E501
        if "verify_tls" in params:
            query_params.append(("verify_tls", params["verify_tls"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/image/metadata",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ImageMetadataResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PythonPackageMetadataResponseMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "author": "str",
        "author_email": "str",
        "classifier": "str",
        "download_url": "str",
        "home_page": "str",
        "keywords": "str",
        "license": "str",
        "maintainer": "str",
        "maintainer_email": "str",
        "metadata_version": "str",
        "name": "str",
        "platform": "str",
        "requires_dist": "str",
        "summary": "str",
        "version": "str",
        "requires_python": "str",
        "description_content_type": "str",
        "project_url": "str",
        "provides_extra": "str",
    }

    attribute_map = {
        "author": "author",
        "author_email": "author_email",
        "classifier": "classifier",
        "download_url": "download_url",
        "home_page": "home_page",
        "keywords": "keywords",
        "license": "license",
        "maintainer": "maintainer",
        "maintainer_email": "maintainer_email",
        "metadata_version": "metadata_version",
        "name": "name",
        "platform": "platform",
        "requires_dist": "requires_dist",
        "summary": "summary",
        "version": "version",
        "requires_python": "requires_python",
        "description_content_type": "description_content_type",
        "project_url": "project_url",
        "provides_extra": "provides_extra",
    }

    def __init__(
        self,
        author=None,
        author_email=None,
        classifier=None,
        download_url=None,
        home_page=None,
        keywords=None,
        license=None,
        maintainer=None,
        maintainer_email=None,
        metadata_version=None,
        name=None,
        platform=None,
        requires_dist=None,
        summary=None,
        version=None,
        requires_python=None,
        description_content_type=None,
        project_url=None,
        provides_extra=None,
    ):  # noqa: E501
        """PythonPackageMetadataResponseMetadata - a model defined in Swagger"""  # noqa: E501
        self._author = None
        self._author_email = None
        self._classifier = None
        self._download_url = None
        self._home_page = None
        self._keywords = None
        self._license = None
        self._maintainer = None
        self._maintainer_email = None
        self._metadata_version = None
        self._name = None
        self._platform = None
        self._requires_dist = None
        self._summary = None
        self._version = None
        self._requires_python = None
        self._description_content_type = None
        self._project_url = None
        self._provides_extra = None
        self.discriminator = None
        self.author = author
        self.author_email = author_email
        self.classifier = classifier
        self.download_url = download_url
        self.home_page = home_page
        self.keywords = keywords
        self.license = license
        self.maintainer = maintainer
        self.maintainer_email = maintainer_email
        self.metadata_version = metadata_version
        self.name = name
        self.platform = platform
        self.requires_dist = requires_dist
        self.summary = summary
        self.version = version
        self.requires_python = requires_python
        self.description_content_type = description_content_type
        self.project_url = project_url
        self.provides_extra = provides_extra

    @property
    def author(self):
        """Gets the author of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the author’s name.  # noqa: E501

        :return: The author of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this PythonPackageMetadataResponseMetadata.

        A string containing the author’s name.  # noqa: E501

        :param author: The author of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if author is None:
            raise ValueError(
                "Invalid value for `author`, must not be `None`"
            )  # noqa: E501

        self._author = author

    @property
    def author_email(self):
        """Gets the author_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the author’s e-mail address.  # noqa: E501

        :return: The author_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._author_email

    @author_email.setter
    def author_email(self, author_email):
        """Sets the author_email of this PythonPackageMetadataResponseMetadata.

        A string containing the author’s e-mail address.  # noqa: E501

        :param author_email: The author_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if author_email is None:
            raise ValueError(
                "Invalid value for `author_email`, must not be `None`"
            )  # noqa: E501

        self._author_email = author_email

    @property
    def classifier(self):
        """Gets the classifier of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Each entry is a string giving a single classification value for the distribution.  # noqa: E501

        :return: The classifier of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._classifier

    @classifier.setter
    def classifier(self, classifier):
        """Sets the classifier of this PythonPackageMetadataResponseMetadata.

        Each entry is a string giving a single classification value for the distribution.  # noqa: E501

        :param classifier: The classifier of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if classifier is None:
            raise ValueError(
                "Invalid value for `classifier`, must not be `None`"
            )  # noqa: E501

        self._classifier = classifier

    @property
    def download_url(self):
        """Gets the download_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the URL from which this version of the distribution can be downloaded.  # noqa: E501

        :return: The download_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this PythonPackageMetadataResponseMetadata.

        A string containing the URL from which this version of the distribution can be downloaded.  # noqa: E501

        :param download_url: The download_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if download_url is None:
            raise ValueError(
                "Invalid value for `download_url`, must not be `None`"
            )  # noqa: E501

        self._download_url = download_url

    @property
    def home_page(self):
        """Gets the home_page of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the URL for the distribution’s home page.  # noqa: E501

        :return: The home_page of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._home_page

    @home_page.setter
    def home_page(self, home_page):
        """Sets the home_page of this PythonPackageMetadataResponseMetadata.

        A string containing the URL for the distribution’s home page.  # noqa: E501

        :param home_page: The home_page of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if home_page is None:
            raise ValueError(
                "Invalid value for `home_page`, must not be `None`"
            )  # noqa: E501

        self._home_page = home_page

    @property
    def keywords(self):
        """Gets the keywords of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A list of additional keywords to be used to assist searching for the distribution in a larger catalog.   # noqa: E501

        :return: The keywords of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this PythonPackageMetadataResponseMetadata.

        A list of additional keywords to be used to assist searching for the distribution in a larger catalog.   # noqa: E501

        :param keywords: The keywords of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if keywords is None:
            raise ValueError(
                "Invalid value for `keywords`, must not be `None`"
            )  # noqa: E501

        self._keywords = keywords

    @property
    def license(self):
        """Gets the license of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Text indicating the license covering the distribution.  # noqa: E501

        :return: The license of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this PythonPackageMetadataResponseMetadata.

        Text indicating the license covering the distribution.  # noqa: E501

        :param license: The license of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if license is None:
            raise ValueError(
                "Invalid value for `license`, must not be `None`"
            )  # noqa: E501

        self._license = license

    @property
    def maintainer(self):
        """Gets the maintainer of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the maintainer’s name at a minimum; additional contact information may be provided.   # noqa: E501

        :return: The maintainer of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._maintainer

    @maintainer.setter
    def maintainer(self, maintainer):
        """Sets the maintainer of this PythonPackageMetadataResponseMetadata.

        A string containing the maintainer’s name at a minimum; additional contact information may be provided.   # noqa: E501

        :param maintainer: The maintainer of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if maintainer is None:
            raise ValueError(
                "Invalid value for `maintainer`, must not be `None`"
            )  # noqa: E501

        self._maintainer = maintainer

    @property
    def maintainer_email(self):
        """Gets the maintainer_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A string containing the maintainer’s e-mail address.  # noqa: E501

        :return: The maintainer_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._maintainer_email

    @maintainer_email.setter
    def maintainer_email(self, maintainer_email):
        """Sets the maintainer_email of this PythonPackageMetadataResponseMetadata.

        A string containing the maintainer’s e-mail address.  # noqa: E501

        :param maintainer_email: The maintainer_email of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if maintainer_email is None:
            raise ValueError(
                "Invalid value for `maintainer_email`, must not be `None`"
            )  # noqa: E501

        self._maintainer_email = maintainer_email

    @property
    def metadata_version(self):
        """Gets the metadata_version of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Version of the file format.  # noqa: E501

        :return: The metadata_version of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """Sets the metadata_version of this PythonPackageMetadataResponseMetadata.

        Version of the file format.  # noqa: E501

        :param metadata_version: The metadata_version of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if metadata_version is None:
            raise ValueError(
                "Invalid value for `metadata_version`, must not be `None`"
            )  # noqa: E501

        self._metadata_version = metadata_version

    @property
    def name(self):
        """Gets the name of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Name of the distribution.  # noqa: E501

        :return: The name of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PythonPackageMetadataResponseMetadata.

        Name of the distribution.  # noqa: E501

        :param name: The name of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def platform(self):
        """Gets the platform of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A Platform specification describing an operating system supported by the distribution.  # noqa: E501

        :return: The platform of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this PythonPackageMetadataResponseMetadata.

        A Platform specification describing an operating system supported by the distribution.  # noqa: E501

        :param platform: The platform of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if platform is None:
            raise ValueError(
                "Invalid value for `platform`, must not be `None`"
            )  # noqa: E501

        self._platform = platform

    @property
    def requires_dist(self):
        """Gets the requires_dist of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Each entry contains a string naming some other distutils project required by this distribution.   # noqa: E501

        :return: The requires_dist of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._requires_dist

    @requires_dist.setter
    def requires_dist(self, requires_dist):
        """Sets the requires_dist of this PythonPackageMetadataResponseMetadata.

        Each entry contains a string naming some other distutils project required by this distribution.   # noqa: E501

        :param requires_dist: The requires_dist of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if requires_dist is None:
            raise ValueError(
                "Invalid value for `requires_dist`, must not be `None`"
            )  # noqa: E501

        self._requires_dist = requires_dist

    @property
    def summary(self):
        """Gets the summary of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        A one-line summary of what the distribution does.  # noqa: E501

        :return: The summary of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this PythonPackageMetadataResponseMetadata.

        A one-line summary of what the distribution does.  # noqa: E501

        :param summary: The summary of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if summary is None:
            raise ValueError(
                "Invalid value for `summary`, must not be `None`"
            )  # noqa: E501

        self._summary = summary

    @property
    def version(self):
        """Gets the version of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        version of the distribution.  # noqa: E501

        :return: The version of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PythonPackageMetadataResponseMetadata.

        version of the distribution.  # noqa: E501

        :param version: The version of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError(
                "Invalid value for `version`, must not be `None`"
            )  # noqa: E501

        self._version = version

    @property
    def requires_python(self):
        """Gets the requires_python of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Python requirements for the distribution.  # noqa: E501

        :return: The requires_python of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._requires_python

    @requires_python.setter
    def requires_python(self, requires_python):
        """Sets the requires_python of this PythonPackageMetadataResponseMetadata.

        Python requirements for the distribution.  # noqa: E501

        :param requires_python: The requires_python of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if requires_python is None:
            raise ValueError(
                "Invalid value for `requires_python`, must not be `None`"
            )  # noqa: E501

        self._requires_python = requires_python

    @property
    def description_content_type(self):
        """Gets the description_content_type of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Content-Type of description text.  # noqa: E501

        :return: The description_content_type of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._description_content_type

    @description_content_type.setter
    def description_content_type(self, description_content_type):
        """Sets the description_content_type of this PythonPackageMetadataResponseMetadata.

        Content-Type of description text.  # noqa: E501

        :param description_content_type: The description_content_type of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if description_content_type is None:
            raise ValueError(
                "Invalid value for `description_content_type`, must not be `None`"
            )  # noqa: E501

        self._description_content_type = description_content_type

    @property
    def project_url(self):
        """Gets the project_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        URL to project.  # noqa: E501

        :return: The project_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._project_url

    @project_url.setter
    def project_url(self, project_url):
        """Sets the project_url of this PythonPackageMetadataResponseMetadata.

        URL to project.  # noqa: E501

        :param project_url: The project_url of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if project_url is None:
            raise ValueError(
                "Invalid value for `project_url`, must not be `None`"
            )  # noqa: E501

        self._project_url = project_url

    @property
    def provides_extra(self):
        """Gets the provides_extra of this PythonPackageMetadataResponseMetadata.  # noqa: E501

        Provided extra of the distribution.  # noqa: E501

        :return: The provides_extra of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :rtype: str
        """
        return self._provides_extra

    @provides_extra.setter
    def provides_extra(self, provides_extra):
        """Sets the provides_extra of this PythonPackageMetadataResponseMetadata.

        Provided extra of the distribution.  # noqa: E501

        :param provides_extra: The provides_extra of this PythonPackageMetadataResponseMetadata.  # noqa: E501
        :type: str
        """
        if provides_extra is None:
            raise ValueError(
                "Invalid value for `provides_extra`, must not be `None`"
            )  # noqa: E501

        self._provides_extra = provides_extra

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PythonPackageMetadataResponseMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPackageMetadataResponseMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
# elyra-aidevsecops-tutorial
# Copyright(C) 2020 Francesco Murdaca
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Download dataset from TensorFlow."""

import os
import logging
import pickle

from pathlib import Path

# set up logging
DEBUG_LEVEL = bool(int(os.getenv("DEBUG_LEVEL", 0)))

if DEBUG_LEVEL:
    logging.basicConfig(level=logging.DEBUG)
else:
    logging.basicConfig(level=logging.INFO)

_LOGGER = logging.getLogger(__name__)

IMPORT_DATASET = str(os.environ.get("TUTORIAL_TF_IMPORT_DATASET", "mnist"))

if IMPORT_DATASET == "mnist":
    _LOGGER.info("Selected MNIST Dataset: MNIST handwritten digits dataset.")
    from tensorflow.keras.datasets import mnist as tf_dataset

elif IMPORT_DATASET == "cifar10":
    _LOGGER.info(
        "Selected cifar10 Dataset: CIFAR10 small images classification dataset."
    )
    from tensorflow.keras.datasets import cifar10 as tf_dataset

elif IMPORT_DATASET == "cifar100":
    _LOGGER.info(
        "Selected cifar100 Dataset: CIFAR100 small images classification dataset."
    )
    from tensorflow.keras.datasets import cifar100 as tf_dataset

elif IMPORT_DATASET == "fashion_mnist":
    _LOGGER.info("Selected fashion_mnist Dataset: Fashion-MNIST dataset.")
    from tensorflow.keras.datasets import fashion_mnist as tf_dataset


def _is_file_downloaded(file_downloaded_path: Path) -> bool:
    """Check if file is already downloaded."""
    if os.path.exists(file_downloaded_path):
        _LOGGER.info("{} already exists, skipping ...".format(file_downloaded_path))
        return True

    return False


def download_dataset_from_tf() -> None:
    """Download Datasets from tf and store them locally."""
    # Set path where to store
    directory_path = Path.cwd().parents[1]
    destination_path = directory_path.joinpath(
        str(os.environ.get("DESTINATION_DATASET", "data/raw"))
    )

    if not os.path.exists(destination_path):
        destination_path.mkdir(parents=True, exist_ok=True)

    # Prepare MNIST data.
    (x_train, y_train), (x_test, y_test) = tf_dataset.load_data()

    dataset = {
        "xdata.pkl": x_train,
        "ydata.pkl": y_train,
        "xtestdata.pkl": x_test,
        "ytestdata.pkl": y_test,
    }

    # Store MNIST data for next step.
    for data_name, data_file in dataset.items():

        file_downloaded_path = destination_path.joinpath(data_name)

        if not _is_file_downloaded(file_downloaded_path):
            output = open(file_downloaded_path, "wb")
            pickle.dump(data_file, output)
            output.close()
            _LOGGER.info("Stored {}".format(file_downloaded_path))


if __name__ == "__main__":
    download_dataset_from_tf()



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PythonPackageMetadataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "parameters": "object",
        "metadata": "PythonPackageMetadataResponseMetadata",
    }

    attribute_map = {"parameters": "parameters", "metadata": "metadata"}

    def __init__(self, parameters=None, metadata=None):  # noqa: E501
        """PythonPackageMetadataResponse - a model defined in Swagger"""  # noqa: E501
        self._parameters = None
        self._metadata = None
        self.discriminator = None
        self.parameters = parameters
        self.metadata = metadata

    @property
    def parameters(self):
        """Gets the parameters of this PythonPackageMetadataResponse.  # noqa: E501


        :return: The parameters of this PythonPackageMetadataResponse.  # noqa: E501
        :rtype: object
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this PythonPackageMetadataResponse.


        :param parameters: The parameters of this PythonPackageMetadataResponse.  # noqa: E501
        :type: object
        """
        if parameters is None:
            raise ValueError(
                "Invalid value for `parameters`, must not be `None`"
            )  # noqa: E501

        self._parameters = parameters

    @property
    def metadata(self):
        """Gets the metadata of this PythonPackageMetadataResponse.  # noqa: E501


        :return: The metadata of this PythonPackageMetadataResponse.  # noqa: E501
        :rtype: PythonPackageMetadataResponseMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PythonPackageMetadataResponse.


        :param metadata: The metadata of this PythonPackageMetadataResponse.  # noqa: E501
        :type: PythonPackageMetadataResponseMetadata
        """
        if metadata is None:
            raise ValueError(
                "Invalid value for `metadata`, must not be `None`"
            )  # noqa: E501

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PythonPackageMetadataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPackageMetadataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from thamos.swagger_client.thoth.advise_api import AdviseApi
from thamos.swagger_client.thoth.build_analysis_api import BuildAnalysisApi
from thamos.swagger_client.thoth.buildlogs_api import BuildlogsApi
from thamos.swagger_client.thoth.git_hub_api import GitHubApi
from thamos.swagger_client.thoth.hardware_api import HardwareApi
from thamos.swagger_client.thoth.image_analysis_api import ImageAnalysisApi
from thamos.swagger_client.thoth.kebechet_api import KebechetApi
from thamos.swagger_client.thoth.provenance_api import ProvenanceApi
from thamos.swagger_client.thoth.python_packages_api import PythonPackagesApi
from thamos.swagger_client.thoth.s2i_api import S2iApi
